﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace WpfDemo
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    using System;
    using System.Windows;
    using ZylSoft.Timers;

    public partial class MainWindow : Window
    {
             
        private WpfApplicationIdleTimer applicationIdleTimer = new WpfApplicationIdleTimer();        
        private IdleTimer idleTimer = new IdleTimer();
        System.Windows.Threading.DispatcherTimer dispatcherTimer = new System.Windows.Threading.DispatcherTimer();        


        public MainWindow()
        {
            InitializeComponent();
            idleTimer.Idle += IdleTimer_Idle;
            idleTimer.Resume += IdleTimer_Resume;
            idleTimer.IdleWarning += IdleTimer_IdleWarning;
            idleTimer.IdleInterval = 8000;
            idleTimer.WarningInterval = 6000;

            applicationIdleTimer.Idle += IdleTimer_Idle;
            applicationIdleTimer.Resume += IdleTimer_Resume;
            applicationIdleTimer.IdleWarning += IdleTimer_IdleWarning;
            applicationIdleTimer.IdleInterval = 8000;
            applicationIdleTimer.WarningInterval = 6000;

            dispatcherTimer.Tick += dispatcherTimer_Tick;
            dispatcherTimer.Interval = new TimeSpan(0, 0, 1);            
        }

        private void dispatcherTimer_Tick(object sender, EventArgs e)
        {
            Application.Current.Dispatcher.Invoke((Action)(() =>
            {
                if (radioButtonSystem.IsChecked == true)
                    lblIdleTime.Content = "Idle Time(ms): " + IdleTimer.GetSystemIdleTime().ToString();
                else
                    lblIdleTime.Content = "Idle Time(ms): " + applicationIdleTimer.GetApplicationIdleTime().ToString();
            }));
        }

        private void IdleTimer_IdleWarning(object sender, EventArgs e)
        {
            Application.Current.Dispatcher.Invoke((Action)(() =>
            {
                textBoxOut.Text += DateTime.Now.Hour.ToString() + ":" + DateTime.Now.Minute.ToString() + ":" +
                DateTime.Now.Second.ToString() + ":" + DateTime.Now.Millisecond.ToString() +
                " - Warning Fired." + Environment.NewLine;
            }));
        }

        private void IdleTimer_Resume(object sender, EventArgs e)
        {
            Application.Current.Dispatcher.Invoke((Action)(() =>
            {
                textBoxOut.Text += DateTime.Now.Hour.ToString() + ":" + DateTime.Now.Minute.ToString() + ":" +
                DateTime.Now.Second.ToString() + ":" + DateTime.Now.Millisecond.ToString() +
                " - Resume Fired." + Environment.NewLine;
            }));
        }

        private void IdleTimer_Idle(object sender, EventArgs e)
        {
            try
            {
                Application.Current.Dispatcher.Invoke((Action)(() =>
                {
                    textBoxOut.Text += DateTime.Now.Hour.ToString() + ":" + DateTime.Now.Minute.ToString() + ":" +
                     DateTime.Now.Second.ToString() + ":" + DateTime.Now.Millisecond.ToString() +
                     " - Idle Fired." + Environment.NewLine;
                }));
            }
            catch (Exception ex)
            { MessageBox.Show(ex.Message); }
        }

        private void Window_Loaded(object sender, RoutedEventArgs e)
        {
            // Initialize any additional logic when the window is loaded.
        }

        private void btnStart_Click(object sender, RoutedEventArgs e)
        {
            // Handle the Start button click.
            if (radioButtonSystem.IsChecked == true)
            {
                idleTimer.Enabled = true;
                applicationIdleTimer.Enabled = false;
            }
            else
            {
                applicationIdleTimer.Enabled = true;
                idleTimer.Enabled = false;
            }
            dispatcherTimer.Start();
            radioButtonSystem.IsEnabled = false;
            radioButtonApplication.IsEnabled = false;
        }

        private void btnStop_Click(object sender, RoutedEventArgs e)
        {
            // Handle the Stop button click.
            idleTimer.Enabled = false;
            applicationIdleTimer.Enabled = false;
            radioButtonSystem.IsEnabled = true;
            radioButtonApplication.IsEnabled = true;
            dispatcherTimer.Stop();
            lblIdleTime.Content = "";
        }

        private void Window_Closed(object sender, EventArgs e)
        {
            if (idleTimer != null)
            {
                idleTimer.Enabled = false;
            }

            if (applicationIdleTimer != null)
                applicationIdleTimer.Enabled = false;

            dispatcherTimer.Stop();
        }        
    }

}
